.. image:: https://travis-ci.org/ARMmbed/yotta.svg
.. image:: https://circleci.com/gh/ARMmbed/yotta.svg?style=svg

yotta is a tool that we're building at `mbed <https://mbed.org>`_ to make it
easier to build better software written in C, C++ or other C-family languages.
It's still early in development, so if you have questions/feedback or issues, please `report them on Github <https://github.com/ARMmbed/yotta/issues>`_.

Installation
============
While yotta is written in python, to use it to build software you'll need several non-python dependencies. Detailed installation instructions and links to installers can be found on the `yotta docs site <http://yottadocs.mbed.com>`_.

Get Started
===========
The best way to get started is to `follow the tutorial <http://yottadocs.mbed.com/tutorial/tutorial.html>`_.

License
=======
yotta is licensed under Apache-2.0
